---
title: PG사 코드
description: JavaScript SDK PG구분코드를 확인할 수 있습니다.
targetVersions:
  - v1
---

|         PG사명        |      code      |
|:---------------------:|:--------------:|
|       KG이니시스      | `html5_inicis` |
|    (구) KG이니시스    |    `inicis`    |
|  KG이니시스 통합인증  |`inicis_unified`|
|        NHN KCP        |      `kcp`     |
|     NHN KCP (정기)    |  `kcp_billing` |
|     NHN KCP 퀵페이    |   `kcp_quick`  |
|   (구) 토스페이먼츠   |     `uplus`    |
|   (신) 토스페이먼츠   | `tosspayments` |
|  (구) 나이스페이먼츠  |     `nice`     |
|  (신) 나이스페이먼츠  |    `nice_v2`   |
|     이지페이(KICC)    |     `kicc`     |
|       카카오페이      |   `kakaopay`   |
|다날휴대폰결제/본인인증|     `danal`    |
|          다날         |  `danal_tpay`  |
|       모빌리언스      |   `mobilians`  |
|         페이코        |     `payco`    |
|      (구) 페이팔      |    `paypal`    |
|      (신) 페이팔      |   `paypal_v2`  |
|        엑심베이       |    `eximbay`   |
|   네이버페이 결제형   |   `naverpay`   |
|   네이버페이 주문형   |    `naverco`   |
|       스마일페이      |   `smilepay`   |
|키움페이((구) 페이조아)|     `daou`     |
|       페이먼트월      |  `paymentwall` |
|        토스페이       |    `tosspay`   |
|     (구) 스마트로     |    `smartro`   |
|     (신) 스마트로     |  `smartro_v2`  |
|      헥토파이낸셜     |    `settle`    |
|헥토파이낸셜 내통장결제|  `settle_acc`  |
|         KSNET         |     `ksnet`    |
|        갤럭시아       |    `galaxia`   |
|      웰컴페이먼츠     |    `welcome`   |
